@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.0.7"
+version = "0.0.8"
 
 # tested on remi version = "2020.3.10"
 import remi.gui as gui
@@ -370,10 +370,14 @@ class CSinSCApp:
   commands = []
   styles = {}
 
-  def __init__(self, width = "100%", height = "100%"):
+  def __init__(self, title = "CSinSchools Application", width = "100%", height = "100%"):
+    if title is None:
+      raise Exception("Please supply a title for the application.")
     self.events = []  
     self.initialised = False
 
+    self.title = title
+
     self.container = gui.Container(width = width, height = height)   
     self.container.style["display"] = "flex;"
     self.container.style["justify-content"] = "center;"
@@ -397,7 +401,7 @@ class CSinSCApp:
     control.widget.onmousemove.do(self.on_mouse_move, control)
 
   def remi_thread(self):
-    start(CSinSCApp.MyApp, debug=False, address='0.0.0.0', port=0, multiple_instance = False, userdata = (self,))    
+    start(CSinSCApp.MyApp, title = self.title, debug=False, address='0.0.0.0', port=0, multiple_instance = True, userdata = (self,))    
 
   def main(self):
     self.initialised = True
